@@ -3,9 +3,16 @@ from datetime import datetime
 from enum import Enum
 from typing import Callable, Literal
 
-from peewee import CharField, DateTimeField, FloatField, IntegerField, Model, SqliteDatabase
+from peewee import (
+    CharField,
+    DateTimeField,
+    FloatField,
+    IntegerField,
+    Model,
+    SqliteDatabase,
+)
 
-from .utils.user_appdirs import retrieve_user_cache_dbfile
+from baca.utils.user_appdirs import retrieve_user_cache_dbfile
 
 db = SqliteDatabase(retrieve_user_cache_dbfile())
 
@@ -75,7 +82,7 @@ class Keymaps:
 
 @dataclass(frozen=True)
 class Config:
-    image_viewer: str | None
+    preferred_image_viewer: str
     max_text_width: str
     text_justification: Literal["default", "center", "full", "right", "left"]
     pretty: bool
