@@ -1,7 +1,7 @@
 import tempfile
 from pathlib import Path
 
-from .. import __appname__
+from baca import __appname__
 
 
 def create_tempdir() -> Path:
